.. _changelog:

ChangeLog
=========

This is a log of changes to yt_astro_analysis over its release history.

Contributors
------------

The `CREDITS file
<https://github.com/yt-project/yt_astro_analysis/blob/master/CREDITS>`__
contains the most up-to-date list of everyone who has contributed to the
yt_astro_analysis source code.

Version 1.0
-----------

This is initial stable release of yt_astro_analysis. Before this, all
code in here was contained in the `yt package's
<https://github.com/yt-project/yt>`__ ``analysis_modules``
submodule. Version 1.0 of yt_astro_analysis is functionally identical
to the ``analysis_modules`` from yt version 3.5.0.
